Learn R Programming

promote (version 1.1.1)

add.metadata: Private function that adds metadata about the model that will be installed on the Promote server the metadata is arranged as key-value pairs

Description

Private function that adds metadata about the model that will be installed on the Promote server the metadata is arranged as key-value pairs

Usage

add.metadata(key, value)

Arguments

key

key name for the metadata entry

value

value for the metadata entry