Learn R Programming

promote (version 1.1.1)

check.image.size: Private function for checking the size of the user's image.

Description

Private function for checking the size of the user's image.

Usage

check.image.size()

Arguments