powered by
This function calls promote's REST API and returns a response formatted as a data frame.
promote.predict(model_name, data, model_owner, raw_input = FALSE, silent = TRUE)
the name of the model you want to call
input data for the model
the owner of the model [optional]
when true, incoming data will NOT be coerced into data.frame
should output of url to console (via promote.post) be silenced? Default is FALSE.
promote.post
FALSE
# NOT RUN { promote.config <- c( username = "your username", apikey = "your apikey", env = "http://sandbox.promotehq.com/" ) # } # NOT RUN { promote.predict("irisModel", iris) # }
Run the code above in your browser using DataLab